@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwps
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
@@ -23,39 +24,42 @@
  * /libwpd2/src/lib/WPXContentListener.cpp 1.12
  */
 
-#include "WPSContentListener.h"
-#include "WPSPageSpan.h"
-#include "libwps_internal.h"
-#include <libwpd/WPXProperty.h>
 #include <stdio.h>
-#ifdef _MSC_VER
-#include <minmax.h>
-#define LIBWPS_MIN min
-#define LIBWPS_MAX max
-#else
-#define LIBWPS_MIN std::min
-#define LIBWPS_MAX std::max
-#endif
 
-#include <vector>
+#include <libwpd/WPXDocumentInterface.h>
+#include <libwpd/WPXProperty.h>
 
-_WPSContentParsingState::_WPSContentParsingState() :
+#include "libwps_tools_win.h"
+#include "WPSPageSpan.h"
+
+#include "WPSContentListener.h"
+
+namespace WPSContentListenerInternal
+{
+struct ListSignature
+{
+	uint16_t m_numbering,m_numstyle,m_numsep;
+
+	bool operator == (ListSignature &y)
+	{
+		return (m_numbering == y.m_numbering) && (m_numstyle == y.m_numstyle) && (m_numsep == y.m_numsep);
+	}
+};
+}
+
+WPSContentParsingState::WPSContentParsingState() :
 	m_textAttributeBits(0),
-	m_spec(0),
 	m_fontSize(12.0f/*WP6_DEFAULT_FONT_SIZE*/),
 	m_fontName(WPXString(/*WP6_DEFAULT_FONT_NAME*/"Times New Roman")),
-	m_lcid(0x409/*en-US*/),
+	m_languageId(0x409/*en-US*/),
 	m_textcolor(0),
 
 	m_fieldcode(0),
 
-	m_codepage(0),
-
 	m_isParagraphColumnBreak(false),
 	m_isParagraphPageBreak(false),
 	m_paragraphJustification(WPS_PARAGRAPH_JUSTIFICATION_LEFT),
 	m_paragraphLineSpacing(1.0f),
-	m_paraLayoutFlags(0),
 
 	m_footnoteId(1),
 	m_endnoteId(1),
@@ -65,6 +69,7 @@ _WPSContentParsingState::_WPSContentParsingState() :
 	m_numsep(0),
 
 	m_curListType(0),
+	m_isOrdered(false),
 
 	m_isDocumentStarted(false),
 	m_isPageSpanOpened(false),
@@ -78,13 +83,14 @@ _WPSContentParsingState::_WPSContentParsingState() :
 
 	m_isParaListItem(false),
 
+	m_nextPageSpanIter(),
 	m_numPagesRemainingInSpan(0),
 
 	m_sectionAttributesChanged(false),
 
 	m_pageFormLength(11.0f),
 	m_pageFormWidth(8.5f),
-	m_pageFormOrientation(PORTRAIT),
+	m_pageFormOrientation(libwps::PORTRAIT),
 
 	m_pageMarginLeft(1.0f),
 	m_pageMarginRight(1.0f),
@@ -94,26 +100,27 @@ _WPSContentParsingState::_WPSContentParsingState() :
 	m_paragraphMarginTop(0.0f),
 	m_paragraphMarginBottom(0.0f),
 	m_paragraphIndentFirst(0.0f),
-	
+
 	m_textBuffer()
 {
 }
 
-_WPSContentParsingState::~_WPSContentParsingState()
+WPSContentParsingState::~WPSContentParsingState()
 {
 }
 
-WPSContentListener::WPSContentListener(std::list<WPSPageSpan> &pageList, WPXDocumentInterface *documentInterface) :
+WPSContentListener::WPSContentListener(std::vector<WPSPageSpan> const &pageList, WPXDocumentInterface *documentInterface) :
 	m_ps(new WPSContentParsingState),
 	m_documentInterface(documentInterface),
-	m_pageList(pageList)
+	m_metaData(), m_tabs(),
+	m_pageList(pageList),
+	m_listFormats()
 {
-	m_ps->m_nextPageSpanIter = pageList.begin();
+	m_ps->m_nextPageSpanIter = m_pageList.begin();
 }
 
 WPSContentListener::~WPSContentListener()
 {
-	DELETEP(m_ps);
 }
 
 void WPSContentListener::startDocument()
@@ -127,7 +134,7 @@ void WPSContentListener::startDocument()
 
 		m_documentInterface->startDocument();
 	}
-	
+
 	m_ps->m_isDocumentStarted = true;
 }
 
@@ -170,12 +177,13 @@ void WPSContentListener::_closeSection()
 		if (m_ps->m_isParagraphOpened)
 			_closeParagraph();
 
-		if (m_ps->m_numbering) {
-		  /* a Hack which calls open/close paragraph (and so closeListLevel)
-		     when a list is opened */
-		  m_ps->m_numbering = 0;
-		  _openParagraph();
-		  _closeParagraph();
+		if (m_ps->m_numbering)
+		{
+			/* a Hack which calls open/close paragraph (and so closeListLevel)
+			   when a list is opened */
+			m_ps->m_numbering = 0;
+			_openParagraph();
+			_closeParagraph();
 		}
 
 		m_documentInterface->closeSection();
@@ -196,28 +204,28 @@ void WPSContentListener::_openPageSpan()
 	if ( m_pageList.empty() || (m_ps->m_nextPageSpanIter == m_pageList.end()))
 	{
 		WPS_DEBUG_MSG(("m_pageList.empty() || (m_ps->m_nextPageSpanIter == m_pageList.end())\n"));
-		throw ParseException();
+		throw libwps::ParseException();
 	}
 
-	WPSPageSpan currentPage = (*m_ps->m_nextPageSpanIter);
+	WPSPageSpan &currentPage = (*m_ps->m_nextPageSpanIter);
 	currentPage.makeConsistent(1);
-	
+
 	WPXPropertyList propList;
 	propList.insert("libwpd:num-pages", currentPage.getPageSpan());
 
-	std::list<WPSPageSpan>::iterator lastPageSpan = --m_pageList.end(); 
+	std::vector<WPSPageSpan>::iterator lastPageSpan = --m_pageList.end();
 	propList.insert("libwpd:is-last-page-span", ((m_ps->m_nextPageSpanIter == lastPageSpan) ? true : false));
 	propList.insert("fo:page-height", currentPage.getFormLength());
 	propList.insert("fo:page-width", currentPage.getFormWidth());
-	if (currentPage.getFormOrientation() == LANDSCAPE)
-		propList.insert("style:print-orientation", "landscape"); 
+	if (currentPage.getFormOrientation() == libwps::LANDSCAPE)
+		propList.insert("style:print-orientation", "landscape");
 	else
-		propList.insert("style:print-orientation", "portrait"); 
+		propList.insert("style:print-orientation", "portrait");
 	propList.insert("fo:margin-left", currentPage.getMarginLeft());
 	propList.insert("fo:margin-right", currentPage.getMarginRight());
 	propList.insert("fo:margin-top", currentPage.getMarginTop());
 	propList.insert("fo:margin-bottom", currentPage.getMarginBottom());
-	
+
 	if (!m_ps->m_isPageSpanOpened)
 		m_documentInterface->openPageSpan(propList);
 
@@ -235,36 +243,37 @@ void WPSContentListener::_openPageSpan()
 			propList.clear();
 			switch ((*iter).getOccurence())
 			{
-			case ODD:
+			case libwps::ODD:
 				propList.insert("libwpd:occurence", "odd");
 				break;
-			case EVEN:
+			case libwps::EVEN:
 				propList.insert("libwpd:occurence", "even");
 				break;
-			case ALL:
+			case libwps::ALL:
 				propList.insert("libwpd:occurence", "all");
 				break;
-			case NEVER:
+			case libwps::NEVER:
 			default:
 				break;
 			}
 
-			if ((*iter).getType() == HEADER)
-				m_documentInterface->openHeader(propList); 
-			else
-				m_documentInterface->openFooter(propList); 
-
-			if ((*iter).getType() == HEADER)
+			if ((*iter).getType() == libwps::HEADER)
+			{
+				m_documentInterface->openHeader(propList);
 				m_documentInterface->closeHeader();
+			}
 			else
-				m_documentInterface->closeFooter(); 
+			{
+				m_documentInterface->openFooter(propList);
+				m_documentInterface->closeFooter();
+			}
 
 			WPS_DEBUG_MSG(("Header Footer Element: type: %i occurence: %i\n",
-				       (*iter).getType(), (*iter).getOccurence()));
+			               (*iter).getType(), (*iter).getOccurence()));
 		}
 	}
 
-	/* Some of this would maybe not be necessary, but it does not do any harm 
+	/* Some of this would maybe not be necessary, but it does not do any harm
 	 * and apparently solves some troubles */
 	m_ps->m_pageFormLength = currentPage.getFormLength();
 	m_ps->m_pageFormWidth = currentPage.getFormWidth();
@@ -285,7 +294,7 @@ void WPSContentListener::_closePageSpan()
 
 		m_documentInterface->closePageSpan();
 	}
-	
+
 	m_ps->m_isPageSpanOpened = false;
 	m_ps->m_isPageSpanBreakDeferred = false;
 }
@@ -337,52 +346,69 @@ void WPSContentListener::_openParagraph()
 		else if (m_ps->m_isParagraphPageBreak)
 			propList.insert("fo:break-before", "page");
 
-		for (unsigned i=0; i < m_tabs.size(); i++) {
+		for (unsigned i=0; i < m_tabs.size(); i++)
+		{
 			WPXPropertyList wpx_td;
-			TabPos bpos = m_tabs[i];
-			wpx_td.insert("style:position",bpos.pos,WPX_INCH);
-			if (bpos.align == WPS_TAB_CENTER) wpx_td.insert("style:type","center");
-			else if (bpos.align == WPS_TAB_RIGHT) wpx_td.insert("style:type","right");
-			// TODO: Decimal tabs depend on locale, obviously.
+			WPSTabPos bpos = m_tabs[i];
+			wpx_td.insert("style:position",bpos.m_pos,WPX_INCH);
+			if (bpos.m_align == WPS_TAB_CENTER) wpx_td.insert("style:type","center");
+			else if (bpos.m_align == WPS_TAB_RIGHT) wpx_td.insert("style:type","right");
+			else if (bpos.m_align == WPS_TAB_DECIMAL)
+			{
+			  wpx_td.insert("style:type","char");
+			  wpx_td.insert("style:char", "."); // Assume a decimal point for now
+			}
 			tabStops.append(wpx_td);
 		}
 
-		if (m_ps->m_numbering) {
+		if (m_ps->m_numbering)
+		{
 			WPXPropertyList pl;
 			int list_type = _getListId();
-			if (list_type != m_ps->m_curListType) {
-				if (m_ps->m_curListType) {
+			if (list_type != m_ps->m_curListType)
+			{
+				if (m_ps->m_curListType)
+				{
 					if (m_ps->m_isOrdered)
 						m_documentInterface->closeOrderedListLevel();
-					else 
+					else
 						m_documentInterface->closeUnorderedListLevel();
 				}
 				/* and open new */
 				pl.insert("libwpd:id",list_type);
-				if (m_ps->m_numbering == WPS_NUMBERING_NUMBER) {
+				if (m_ps->m_numbering == WPS_NUMBERING_NUMBER)
+				{
 					m_ps->m_isOrdered = true;
 					m_documentInterface->openOrderedListLevel(pl);
-				} else {
+				}
+				else
+				{
 					m_ps->m_isOrdered = false;
 					m_documentInterface->openUnorderedListLevel(pl);
 				}
 				m_ps->m_curListType = list_type;
 			}
-		} else {
-			if (m_ps->m_curListType != 0) {
+		}
+		else
+		{
+			if (m_ps->m_curListType != 0)
+			{
 				if (m_ps->m_isOrdered)
 					m_documentInterface->closeOrderedListLevel();
-				else 
+				else
 					m_documentInterface->closeUnorderedListLevel();
 				m_ps->m_curListType = 0;
 			}
 		}
 
-		if (!m_ps->m_isParagraphOpened) {
-			if (m_ps->m_curListType) {
+		if (!m_ps->m_isParagraphOpened)
+		{
+			if (m_ps->m_curListType)
+			{
 				m_documentInterface->openListElement(propList, tabStops);
 				m_ps->m_isParaListItem = true;
-			} else 
+			}
+			else
 				m_documentInterface->openParagraph(propList, tabStops);
 		}
 
@@ -399,10 +425,12 @@ void WPSContentListener::_closeParagraph()
 		if (m_ps->m_isSpanOpened)
 			_closeSpan();
 
-		if (m_ps->m_isParaListItem) {
+		if (m_ps->m_isParaListItem)
+		{
 			m_documentInterface->closeListElement();
 			m_ps->m_isParaListItem = false;
-		} else
+		}
+		else
 			m_documentInterface->closeParagraph();
 	}
 
@@ -416,14 +444,14 @@ void WPSContentListener::_openSpan()
 {
 	if (!m_ps->m_isParagraphOpened)
 		_openParagraph();
-	
+
 	uint8_t fontSizeAttributes = (uint8_t)(m_ps->m_textAttributeBits & 0x0000001f);
 	float fontSizeChange = 0.0f;
 	switch (fontSizeAttributes)
 	{
 	case 0x01:  // Extra large
 		fontSizeChange = 2.0f;
-		break;	
+		break;
 	case 0x02: // Very large
 		fontSizeChange = 1.5f;
 		break;
@@ -442,9 +470,9 @@ void WPSContentListener::_openSpan()
 	}
 
 	WPXPropertyList propList;
- 	if (m_ps->m_textAttributeBits & WPS_SUPERSCRIPT_BIT)
+	if (m_ps->m_textAttributeBits & WPS_SUPERSCRIPT_BIT)
 		propList.insert("style:text-position", "super 58%");
- 	else if (m_ps->m_textAttributeBits & WPS_SUBSCRIPT_BIT)
+	else if (m_ps->m_textAttributeBits & WPS_SUBSCRIPT_BIT)
 		propList.insert("style:text-position", "sub 58%");
 	if (m_ps->m_textAttributeBits & WPS_ITALICS_BIT)
 		propList.insert("fo:font-style", "italic");
@@ -452,40 +480,57 @@ void WPSContentListener::_openSpan()
 		propList.insert("fo:font-weight", "bold");
 	if (m_ps->m_textAttributeBits & WPS_STRIKEOUT_BIT)
 		propList.insert("style:text-line-through-type", "single");
-	if (m_ps->m_textAttributeBits & WPS_DOUBLE_UNDERLINE_BIT) 
+	if (m_ps->m_textAttributeBits & WPS_DOUBLE_UNDERLINE_BIT)
 		propList.insert("style:text-underline-type", "double");
- 	else if (m_ps->m_textAttributeBits & WPS_UNDERLINE_BIT) 
+	else if (m_ps->m_textAttributeBits & WPS_UNDERLINE_BIT)
 		propList.insert("style:text-underline-type", "single");
-	if (m_ps->m_textAttributeBits & WPS_OUTLINE_BIT) 
+	if (m_ps->m_textAttributeBits & WPS_OUTLINE_BIT)
 		propList.insert("style:text-outline", "true");
-	if (m_ps->m_textAttributeBits & WPS_SMALL_CAPS_BIT) 
+	if (m_ps->m_textAttributeBits & WPS_SMALL_CAPS_BIT)
 		propList.insert("fo:font-variant", "small-caps");
 	if (m_ps->m_textAttributeBits & WPS_ALL_CAPS_BIT)
 		propList.insert("fo:text-transform", "uppercase");
-	if (m_ps->m_textAttributeBits & WPS_BLINK_BIT) 
+	if (m_ps->m_textAttributeBits & WPS_BLINK_BIT)
 		propList.insert("style:text-blinking", "true");
-	if (m_ps->m_textAttributeBits & WPS_SHADOW_BIT) 
+	if (m_ps->m_textAttributeBits & WPS_SHADOW_BIT)
 		propList.insert("fo:text-shadow", "1pt 1pt");
 	if (m_ps->m_textAttributeBits & WPS_EMBOSS_BIT)
 		propList.insert("style:font-relief", "embossed");
 	else if (m_ps->m_textAttributeBits & WPS_ENGRAVE_BIT)
 		propList.insert("style:font-relief", "engraved");
-	if (m_ps->m_lcid)
-		propList.insert("fo:language", getLangFromLCID(m_ps->m_lcid).c_str());
+	if (m_ps->m_languageId)
+	{
+		std::string lang = libwps_tools_win::Language::localeName(m_ps->m_languageId);
+		if (lang.length())
+		{
+			std::string language(lang);
+			std::string country("none");
+			if (lang.length() > 3 && lang[2]=='_')
+			{
+				country=lang.substr(3);
+				language=lang.substr(0,2);
+			}
+			propList.insert("fo:language", language.c_str());
+			propList.insert("fo:country", country.c_str());
+		}
+		else
+		{
+			propList.insert("fo:language", "none");
+			propList.insert("fo:country", "none");
+		}
+	}
 
 	if (m_ps->m_fontName.len())
 		propList.insert("style:font-name", m_ps->m_fontName.cstr());
 	propList.insert("fo:font-size", fontSizeChange*m_ps->m_fontSize, WPX_POINT);
-	/*if (m_ps->m_lcid)
-		propList.insert("fo:lang",lcid2code(m_ps->lcid));*/
-
 	// Here we give the priority to the redline bit over the font color.
 	// When redline finishes, the color is back.
 	if (m_ps->m_textAttributeBits & WPS_REDLINE_BIT)
 		propList.insert("fo:color", "#ff3333");  // #ff3333 = a nice bright red
-	else {
+	else
+	{
 		char color[20];
-		sprintf(color,"%06x",m_ps->m_textcolor);
+		sprintf(color,"#%06x",m_ps->m_textcolor);
 		propList.insert("fo:color", color);
 	}
 
@@ -503,7 +548,7 @@ void WPSContentListener::_closeSpan()
 
 		m_documentInterface->closeSpan();
 	}
-	
+
 	m_ps->m_isSpanOpened = false;
 }
 
@@ -513,21 +558,21 @@ void WPSContentListener::insertBreak(const uint8_t breakType)
 	{
 	case WPS_COLUMN_BREAK:
 		if (!m_ps->m_isPageSpanOpened)
-			_openSpan();				
+			_openSpan();
 		if (m_ps->m_isParagraphOpened)
 			_closeParagraph();
 		m_ps->m_isParagraphColumnBreak = true;
 		break;
 	case WPS_PAGE_BREAK:
 		if (!m_ps->m_isPageSpanOpened)
-			_openSpan();				
+			_openSpan();
 		if (m_ps->m_isParagraphOpened)
 			_closeParagraph();
 		m_ps->m_isParagraphPageBreak = true;
 		break;
 		// TODO: (.. line break?)
 	}
-		
+
 	switch (breakType)
 	{
 	case WPS_PAGE_BREAK:
@@ -538,7 +583,7 @@ void WPSContentListener::insertBreak(const uint8_t breakType)
 		{
 			if (!m_ps->m_isParagraphOpened)
 				_closePageSpan();
-		    else
+			else
 				m_ps->m_isPageSpanBreakDeferred = true;
 		}
 	default:
@@ -546,16 +591,10 @@ void WPSContentListener::insertBreak(const uint8_t breakType)
 	}
 }
 
-void WPSContentListener::setSpec(const uint16_t specCode)
-{
-	_closeSpan();
-	m_ps->m_spec = specCode;
-}
-
 void WPSContentListener::setTextFont(const WPXString fontName)
 {
 	_closeSpan();
-	m_ps->m_fontName = fontName;	
+	m_ps->m_fontName = fontName;
 }
 
 void WPSContentListener::setFontSize(const uint16_t fontSize)
@@ -564,16 +603,16 @@ void WPSContentListener::setFontSize(const uint16_t fontSize)
 	m_ps->m_fontSize=float(fontSize);
 }
 
-void WPSContentListener::setLCID(const uint32_t lcid)
+void WPSContentListener::setFontAttributes(const uint32_t fontAttributes)
 {
 	_closeSpan();
-	m_ps->m_lcid=lcid;
+	m_ps->m_textAttributeBits=fontAttributes;
 }
 
-void WPSContentListener::setCodepage(const int codepage)
+void WPSContentListener::setLanguageID(const uint32_t lcid)
 {
-	if (codepage == 0) return;
-	m_ps->m_codepage = codepage;
+	_closeSpan();
+	m_ps->m_languageId=lcid;
 }
 
 void WPSContentListener::setColor(const unsigned int rgb)
@@ -587,13 +626,8 @@ void WPSContentListener::setAlign(const uint8_t align)
 	m_ps->m_paragraphJustification = align;
 }
 
-void WPSContentListener::setParaFlags(const uint32_t flags)
-{
-	m_ps->m_paraLayoutFlags = flags;
-}
-
-void WPSContentListener::setMargins(const float first, const float left, 
-									const float right,const float before, const float after)
+void WPSContentListener::setMargins(const float first, const float left,
+                                    const float right,const float before, const float after)
 {
 	m_ps->m_paragraphMarginLeft = left;
 	m_ps->m_paragraphMarginRight = right;
@@ -602,7 +636,7 @@ void WPSContentListener::setMargins(const float first, const float left,
 	m_ps->m_paragraphMarginBottom = after;
 }
 
-void WPSContentListener::setTabs(std::vector<TabPos> &tabs)
+void WPSContentListener::setTabs(std::vector<WPSTabPos> &tabs)
 {
 	m_tabs = tabs;
 }
@@ -616,12 +650,12 @@ void WPSContentListener::setNumberingProp(const uint16_t type, const uint16_t se
 {
 	if (m_ps->m_numbering == WPS_NUMBERING_NONE)
 		m_ps->m_numbering = WPS_NUMBERING_NUMBER;
-	
+
 	m_ps->m_numstyle = type;
 	m_ps->m_numsep = sep;
 }
 
-void WPSContentListener::insertEOL() 
+void WPSContentListener::insertEOL()
 {
 	if (!m_ps->m_isParagraphOpened)
 		_openSpan();
@@ -629,19 +663,65 @@ void WPSContentListener::insertEOL()
 		_closeParagraph();
 }
 
-uint16_t WPSContentListener::getSpec() const
-{
-	return m_ps->m_spec;
-}
-
-
-void WPSContentListener::insertCharacter(const uint16_t character) 
+void WPSContentListener::insertCharacter(const uint16_t character)
 {
 	if (!m_ps->m_isSpanOpened)
 		_openSpan();
 	m_ps->m_textBuffer.append(character);
 }
 
+void WPSContentListener::insertUnicodeCharacter(uint32_t character)
+{
+	if (!m_ps->m_isSpanOpened)
+		_openSpan();
+	if (character == 0xfffd)
+		return;
+	uint8_t first;
+	int len;
+	if (character < 0x80)
+	{
+		first = 0;
+		len = 1;
+	}
+	else if (character < 0x800)
+	{
+		first = 0xc0;
+		len = 2;
+	}
+	else if (character < 0x10000)
+	{
+		first = 0xe0;
+		len = 3;
+	}
+	else if (character < 0x200000)
+	{
+		first = 0xf0;
+		len = 4;
+	}
+	else if (character < 0x4000000)
+	{
+		first = 0xf8;
+		len = 5;
+	}
+	else
+	{
+		first = 0xfc;
+		len = 6;
+	}
+
+	uint8_t outbuf[6] = { 0, 0, 0, 0, 0, 0 };
+	int i;
+	for (i = len - 1; i > 0; --i)
+	{
+		outbuf[i] = (character & 0x3f) | 0x80;
+		character >>= 6;
+	}
+	outbuf[0] = character | first;
+
+	for (i = 0; i < len; i++)
+		m_ps->m_textBuffer.append(outbuf[i]);
+}
+
 void WPSContentListener::setFieldType(uint16_t code)
 {
 	m_ps->m_fieldcode = code;
@@ -651,7 +731,8 @@ void WPSContentListener::insertField()
 {
 	WPXPropertyList pl;
 
-	if (m_ps->m_fieldcode == WPS_FIELD_PAGE) {
+	if (m_ps->m_fieldcode == WPS_FIELD_PAGE)
+	{
 		_flushText();
 		pl.insert("style:num-format","1");
 		m_documentInterface->insertField("text:page-number",pl);
@@ -722,22 +803,22 @@ void WPSContentListener::_insertText(const WPXString &textBuffer)
 {
 	if (textBuffer.len() <= 0)
 		return;
-        
+
 	WPXString tmpText;
 	const char ASCII_SPACE = 0x0020;
 
 	int numConsecutiveSpaces = 0;
-        WPXString::Iter i(textBuffer);
-	for (i.rewind(); i.next();) 
+	WPXString::Iter i(textBuffer);
+	for (i.rewind(); i.next();)
 	{
 		if (*(i()) == ASCII_SPACE)
 			numConsecutiveSpaces++;
 		else
 			numConsecutiveSpaces = 0;
 
-		if (numConsecutiveSpaces > 1) 
+		if (numConsecutiveSpaces > 1)
 		{
-			if (tmpText.len() > 0) 
+			if (tmpText.len() > 0)
 			{
 				m_documentInterface->insertText(tmpText);
 				tmpText.clear();
@@ -745,7 +826,7 @@ void WPSContentListener::_insertText(const WPXString &textBuffer)
 
 			m_documentInterface->insertSpace();
 		}
-		else 
+		else
 		{
 			tmpText.append(i());
 		}
@@ -756,14 +837,15 @@ void WPSContentListener::_insertText(const WPXString &textBuffer)
 
 int WPSContentListener::_getListId()
 {
-	ListSignature l;
-	l.a = m_ps->m_numbering;
-	l.b = m_ps->m_numstyle;
-	l.c = m_ps->m_numsep;
+	WPSContentListenerInternal::ListSignature l;
+	l.m_numbering = m_ps->m_numbering;
+	l.m_numstyle = m_ps->m_numstyle;
+	l.m_numsep = m_ps->m_numsep;
 
-	if (l.a == 0) return 0;
+	if (l.m_numbering == 0) return 0;
 
-	for (unsigned i=0; i < m_listFormats.size(); i++) {
+	for (unsigned i=0; i < m_listFormats.size(); i++)
+	{
 		if (m_listFormats[i]==l)
 			return i+1;
 	}
@@ -774,21 +856,23 @@ int WPSContentListener::_getListId()
 	pl.insert("libwpd:id",listid);
 	pl.insert("libwpd:level",1);
 
-	if (m_ps->m_numbering == WPS_NUMBERING_NUMBER) {
+	if (m_ps->m_numbering == WPS_NUMBERING_NUMBER)
+	{
 		const char *nst = "1";
-		switch (m_ps->m_numstyle) {
-			case WPS_NUM_STYLE_LLATIN:
-				nst = "a";
-				break;
-			case WPS_NUM_STYLE_ULATIN:
-				nst = "A";
-				break;
-			case WPS_NUM_STYLE_LROMAN:
-				nst = "i";
-				break;
-			case WPS_NUM_STYLE_UROMAN:
-				nst = "I";
-				break;
+		switch (m_ps->m_numstyle)
+		{
+		case WPS_NUM_STYLE_LLATIN:
+			nst = "a";
+			break;
+		case WPS_NUM_STYLE_ULATIN:
+			nst = "A";
+			break;
+		case WPS_NUM_STYLE_LROMAN:
+			nst = "i";
+			break;
+		case WPS_NUM_STYLE_UROMAN:
+			nst = "I";
+			break;
 		};
 		pl.insert("style:num-format", nst);
 
@@ -797,10 +881,14 @@ int WPSContentListener::_getListId()
 		pl.insert("text:start-value",1);
 
 		m_documentInterface->defineOrderedListLevel(pl);
-	} else {
+	}
+	else
+	{
 		pl.insert("text:bullet-char","*");
 		m_documentInterface->defineUnorderedListLevel(pl);
 	}
 
 	return listid;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
